==> subdivide-1.1.0-immer-alpha-7.tgz: package/lib/index.js <==
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import React, { Component } from "react";
import { Subdivide, SubdivideProvider, usePane, useSubdivide } from "./components";
import { render, createRoot } from "react-dom";
var urls = [{
  url: "https://twitter.com",
  label: "NCR"
}, {
  url: "http://coenraets.org/present/react/#0",
  label: "Slide Show"
}, {
  url: "http://jsbin.com/vexawi/2/edit?js",
  label: "jsbin"
}, {
  url: "http://www.hccs.edu/media/houston-community-college/district/academic-affairs/4_Approved_Faculty_CurriculumVitae_Sample_02Feb2011.pdf?js",
  label: "CV"
}];
var colors = [{
  url: "red",
  label: "Red"
}, {
  url: "green",
  label: "Green"
}, {
  url: "blue",
  label: "Blue"
}, {
  url: "hotpink",
  label: "HotPink"
}];

var Iframe = function Iframe(_ref) {
  var src = _ref.src;
  return React.createElement("iframe", {
    title: "me",
    src: src,
    frameBorder: "0",
    style: {
      width: "100%",
      height: "100%"
    }
  });
};

var Color = function Color(_ref2) {
  var src = _ref2.src;
  var pane = usePane();

  var _useSubdivide = useSubdivide(),
      state = _useSubdivide.state,
      actions = _useSubdivide.actions;

  return React.createElement("div", {
    style: {
      width: "100%",
      height: "100%",
      backgroundColor: src
    }
  }, "color: ", src, pane.id, React.createElement("button", {
    onClick: function onClick() {
      return actions.setDividerStyles({
        borderSize: 1,
        cellSpacing: 7,
        touchMargin: 2,
        borderColor: "#c0c0d0",
        cellSpaceColor: "#e0e0e0"
      });
    }
  }, "divider styles"), JSON.stringify(Object.keys(actions), null, 2), React.createElement("pre", null, JSON.stringify(state, null, 2)));
};

var Link = function Link(_ref3) {
  var onSelect = _ref3.onSelect,
      children = _ref3.children;
  return React.createElement("div", {
    onClick: onSelect,
    style: styles.linkOuter
  }, React.createElement("div", null, children));
};

var Menu = function Menu(_ref4) {
  var urls = _ref4.urls,
      _onSelect = _ref4.onSelect;
  return React.createElement("div", {
    style: styles.menu
  }, urls.map(function (_ref5, i) {
    var url = _ref5.url,
        label = _ref5.label;
    return React.createElement(Link, {
      onSelect: function onSelect() {
        return _onSelect(url);
      },
      key: "n" + i
    }, label);
  }));
};

var Chooser =
/*#__PURE__*/
function (_Component) {
  _inherits(Chooser, _Component);

  function Chooser(props, ctx) {
    var _this;

    _classCallCheck(this, Chooser);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Chooser).call(this, props, ctx));
    _this.state = {
      url: ""
    };
    return _this;
  }

  _createClass(Chooser, [{
    key: "onSelect",
    value: function onSelect(url) {
      this.setState({
        url: url
      });
    }
  }, {
    key: "render",
    value: function render() {
      var url = this.state.url;
      return url === "" ? React.createElement(Menu, {
        urls: colors,
        onSelect: this.onSelect.bind(this)
      }) : React.createElement(Color, {
        src: url
      });
    }
  }]);

  return Chooser;
}(Component);

var App = function App() {
  return React.createElement("div", {
    style: {
      width: "100vw",
      height: "100vh",
      padding: 50,
      display: "flex",
      flexDirection: "column",
      boxSizing: "border-box"
    }
  }, React.createElement(SubdivideProvider, null, React.createElement(Subdivide, {
    DefaultComponent: Chooser,
    style: {
      width: "auto",
      height: "auto",
      flex: "1",
      position: "relative"
    }
  })), React.createElement("div", {
    style: {
      height: 100
    }
  }), React.createElement(SubdivideProvider, null, React.createElement(Subdivide, {
    DefaultComponent: Chooser,
    style: {
      width: "auto",
      height: "auto",
      flex: "1",
      position: "relative"
    }
  })));
};

var styles = {
  menu: {
    display: "flex",
    flexDirection: "column",
    margin: 2,
    fontFamily: "sans-serif",
    colof: "#333"
  },
  linkOuter: {
    display: "flex",
    flex: 1,
    height: 50,
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: "#eee",
    cursor: "pointer",
    transition: "color .3s",
    margin: 2
  }
}; //const rootElement = document.getElementById("root");

createRoot(document.getElementById("root")).render(React.createElement(React.StrictMode, null, React.createElement(App, null))); // render(
//   <React.StrictMode>
//     <App />
//   </React.StrictMode>,
//   document.getElementById("root")
// );

==> subdivide-1.2.0-immer-alpha-7.tgz: package/lib/index.js <==
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import React, { Component } from "react";
import { Subdivide, SubdivideProvider, usePane, useSubdivide } from "./components";
import { render, createRoot } from "react-dom";
var urls = [{
  url: "https://twitter.com",
  label: "NCR"
}, {
  url: "http://coenraets.org/present/react/#0",
  label: "Slide Show"
}, {
  url: "http://jsbin.com/vexawi/2/edit?js",
  label: "jsbin"
}, {
  url: "http://www.hccs.edu/media/houston-community-college/district/academic-affairs/4_Approved_Faculty_CurriculumVitae_Sample_02Feb2011.pdf?js",
  label: "CV"
}];
var colors = [{
  url: "red",
  label: "Red"
}, {
  url: "green",
  label: "Green"
}, {
  url: "blue",
  label: "Blue"
}, {
  url: "hotpink",
  label: "HotPink"
}];

var Iframe = function Iframe(_ref) {
  var src = _ref.src;
  return React.createElement("iframe", {
    title: "me",
    src: src,
    frameBorder: "0",
    style: {
      width: "100%",
      height: "100%"
    }
  });
};

var Color = function Color(_ref2) {
  var src = _ref2.src;
  var pane = usePane();

  var _useSubdivide = useSubdivide(),
      state = _useSubdivide.state,
      actions = _useSubdivide.actions;

  return React.createElement("div", {
    style: {
      width: "100%",
      height: "100%",
      backgroundColor: src
    }
  }, "color: ", src, pane.id, React.createElement("button", {
    onClick: function onClick() {
      return actions.setDividerStyles({
        borderSize: 1,
        cellSpacing: 7,
        touchMargin: 2,
        borderColor: "#c0c0d0",
        cellSpaceColor: "#e0e0e0"
      });
    }
  }, "divider styles"), JSON.stringify(Object.keys(actions), null, 2), React.createElement("pre", null, JSON.stringify(state, null, 2)));
};

var Link = function Link(_ref3) {
  var onSelect = _ref3.onSelect,
      children = _ref3.children;
  return React.createElement("div", {
    onClick: onSelect,
    style: styles.linkOuter
  }, React.createElement("div", null, children));
};

var Menu = function Menu(_ref4) {
  var urls = _ref4.urls,
      _onSelect = _ref4.onSelect;
  return React.createElement("div", {
    style: styles.menu
  }, urls.map(function (_ref5, i) {
    var url = _ref5.url,
        label = _ref5.label;
    return React.createElement(Link, {
      onSelect: function onSelect() {
        return _onSelect(url);
      },
      key: "n" + i
    }, label);
  }));
};

var Chooser =
/*#__PURE__*/
function (_Component) {
  _inherits(Chooser, _Component);

  function Chooser(props, ctx) {
    var _this;

    _classCallCheck(this, Chooser);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Chooser).call(this, props, ctx));
    _this.state = {
      url: ""
    };
    return _this;
  }

  _createClass(Chooser, [{
    key: "onSelect",
    value: function onSelect(url) {
      this.setState({
        url: url
      });
    }
  }, {
    key: "render",
    value: function render() {
      var url = this.state.url;
      return url === "" ? React.createElement(Menu, {
        urls: colors,
        onSelect: this.onSelect.bind(this)
      }) : React.createElement(Color, {
        src: url
      });
    }
  }]);

  return Chooser;
}(Component);

var App = function App() {
  return React.createElement("div", {
    style: {
      width: "100vw",
      height: "100vh",
      padding: 50,
      display: "flex",
      flexDirection: "column",
      boxSizing: "border-box"
    }
  }, React.createElement(SubdivideProvider, null, React.createElement(Subdivide, {
    DefaultComponent: Chooser,
    style: {
      width: "auto",
      height: "auto",
      flex: "1",
      backgroundColor: "#fdf",
      position: "relative"
    }
  })), React.createElement("div", {
    style: {
      height: 100
    }
  }));
};

var styles = {
  menu: {
    display: "flex",
    flexDirection: "column",
    margin: 2,
    fontFamily: "sans-serif",
    colof: "#333"
  },
  linkOuter: {
    display: "flex",
    flex: 1,
    height: 50,
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: "#eee",
    cursor: "pointer",
    transition: "color .3s",
    margin: 2
  }
}; // const rootElement = document.getElementById("root");
// createRoot(document.getElementById("root")).render(
//   <React.StrictMode>
//     <App />
//   </React.StrictMode>
// );

render( //  <React.StrictMode>
React.createElement(App, null), //  </React.StrictMode>
document.getElementById("root"));
